// PWM sur les 5 LED bleues
// Pierre-Yves Rochat, 2020, EPFL, pyr@pyr.ch

#include <msp430.h>
#include <stdint.h>

#include <PYR_CarteBlanche.h>
#include <PYR_5PWM.h>

void InitPWM() {
  // Initialisation du Timer :
  // choix de l'horloge et mode continu
  TA0CTL = TASSEL_2 | ID_0 | MC_2 | TAIE;
  // Interrupt On sur les 5 registres de comparaison :
  TA0CCTL0 = TA0CCTL1 = TA0CCTL2 = TA0CCTL3 = TA0CCTL4 = CCIE;
  __enable_interrupt(); // Active l'ensemble des interruption
}


// Timer_A0 Interrupt Vector handler
#pragma vector=TIMER0_A0_VECTOR
__interrupt void Timer_A0(void) { // CCR0
  Led4Off;
}

// Timer_A1 Interrupt Vector (TAIV) handler
#pragma vector=TIMER0_A1_VECTOR
__interrupt void Timer_A1(void) {
  switch(TA0IV) {
  case  2: // CCR1 :
    Led5Off;
    break;
  case  4: // CCR2 :
    Led6Off;
    break;
  case  6: // CCR3 :
   Led7Off;
   break;
  case  8: // CCR4 :
    Led8Off;
    break;
  case 14: // Overflow
    if (pwm4>=LIMITE_MIN_PWM) { TA0CCR0 = pwm4; Led4On; }
    if (pwm5>=LIMITE_MIN_PWM) { TA0CCR1 = pwm5; Led5On; }
    if (pwm6>=LIMITE_MIN_PWM) { TA0CCR2 = pwm6; Led6On; }
    if (pwm7>=LIMITE_MIN_PWM) { TA0CCR3 = pwm7; Led7On; }
    if (pwm8>=LIMITE_MIN_PWM) { TA0CCR4 = pwm8; Led8On; }
    debCycle = 1; // signale le début du cycle
    break;
  }
}

